Description: Learn about planet Mars’ atmosphere, water supply and the possibility to support life, plus, findings from the Mars exploration rover mission.

Follow
TRENDING: Skywatching Guide // Space Webcasts // Mars Rover Curiosity // Solar Flares // Space Photos // Space Videos // Telescopes for Beginners
Reference:

# Mars Facts: Life, Water and Robots on the Red Planet

by Charles Q. Choi, Space.com Contributor | November 04, 2014 09:00pm ET

NASA's Hubble Space Telescope snapped this shot of Mars on Aug. 26, 2003, when the Red Planet was 34.7 million miles from Earth. The picture was taken just 11 hours before Mars made its closest approach to us in 60,000 years. Credit: NASA/ESA View full size image

Mars is the fourth planet from the sun. Befitting the red planet's bloody color, the Romans named it after their god of war. The Romans copied the ancient Greeks, who also named the planet after their god of war, Ares. Other civilizations also typically gave the planet names based on its color — for example, the Egyptians named it "Her Desher," meaning "the red one," while ancient Chinese astronomers dubbed it "the fire star."

## Physical characteristics

Regolith

The bright rust color Mars is known for is due to iron-rich minerals in its regolith — the loose dust and rock covering its surface. The soil of Earth is a kind of regolith, albeit one loaded with organic content. According to NASA, the iron minerals oxidize, or rust, causing the soil to look red.

Geology

The cold, thin atmosphere means liquid water currently cannot exist on the Martian surface for any length of time. This means that although this desert planet is just half the diameter of Earth, it has the same amount of dry land.

The red planet is home to both the highest mountain and the deepest, longest valley in the solar system. Olympus Mons is roughly 17 miles (27 kilometers) high, about three times as tall as Mount Everest, while the Valles Marineris system of valleys — named after the Mariner 9 probe that discovered it in 1971 — can go as deep as 6 miles (10 km) and runs east-west for roughly 2,500 miles (4,000 km), about one-fifth of the distance around Mars and close to the width of Australia or the distance from Philadelphia to San Diego.

Space.com Exclusive T-shirt. Available to Populate Mars. Buy Now
Credit: Space.com Store
View full size image

Mars has the largest volcanoes in the solar system, including Olympus Mons, which is about 370 miles (600 km) in diameter, wide enough to cover the entire state of New Mexico. It is a shield volcano, with slopes that rise gradually like those of Hawaiian volcanoes, and was created by eruptions of lavas that flowed for long distances before solidifying. Mars also has many other kinds of volcanic landforms, from small, steep-sided cones to enormous plains coated in hardened lava. Some minor eruptions might still occur on the planet.

Scientists think the Valles Marineris formed mostly by rifting of the crust as it got stretched. Individual canyons within the system are as much as 60 miles (100 km) wide. They merge in the central part of the Valles Marineris in a region as much as 370 miles (600 km) wide. Large channels emerging from the ends of some canyons and layered sediments within suggest the canyons might once have been filled with liquid water.

Channels, valleys, and gullies are found all over Mars, and suggest that liquid water might have flowed across the planet's surface in recent times. Some channels can be 60 miles (100 km) wide and 1,200 miles (2,000 km) long. Water may still lie in cracks and pores in underground rock.

Many regions of Mars are flat, low-lying plains. The lowest of the northern plains are among the flattest, smoothest places in the solar system, potentially created by water that once flowed across the Martian surface. The northern hemisphere mostly lies at a lower elevation than the southern hemisphere, suggesting the crust may be thinner in the north than in the south. This difference between the north and south might be due to a very large impact shortly after the birth of Mars.

The number of craters on Mars varies dramatically from place to place, depending on how old the surface is. Much of the surface of the southern hemisphere is extremely old, and so has many craters — including the planet's largest, 1,400-mile-wide (2,300 km) Hellas Planitia — while that of northern hemisphere is younger and so has fewer craters. Some volcanoes have few craters, which suggests they erupted recently, with the resulting lava covering up any old craters. Some craters have unusual-looking deposits of debris around them resembling solidified mudflows, potentially indicating that impactor hit underground water or ice.

## Polar caps

Vast deposits of what appear to be finely layered stacks of water ice and dust extend from the poles to latitudes of about 80 degrees in both hemispheres. These were probably deposited by the atmosphere over long spans of time. On top of much of these layered deposits in both hemispheres are caps of water ice that remain frozen all year round. Additional seasonal caps of frost appear in the wintertime. These are made of solid carbon dioxide, also known as "dry ice," which has condensed from carbon dioxide gas in the atmosphere, and in the deepest part of the winter, this frost can extend from the poles to latitudes as low as 45 degrees, or halfway to the equator. The dry ice layer appears to have a fluffy texture, like freshly fallen snow, according to the report in the Journal of Geophysical Research-Planets.

Mars 12 inch Globe Buy Here
Credit: Space.com Store
View full size image

## Climate

Mars is much colder than Earth, in large part due to its greater distance from the sun. The average temperature is about minus 80 degrees Fahrenheit (minus 60 degrees Celsius), although they can vary from minus 195 F (minus 125 C) near the poles during the winter to as much as 70 F (20 C) at midday near the equator.

The carbon-dioxide-rich atmosphere of Mars is also roughly 100 times less dense than Earth's on average, but it is nevertheless thick enough to support weather, clouds and winds. The density of the atmosphere varies seasonally, as winter forces carbon dioxide to freeze out of the Martian air.

NASA’s Mars Reconnaissance Orbiter found the first definitive detections of carbon-dioxide snow clouds, making Mars the only body in the solar system known to host the unusual winter weather. The red planet also causes water-ice snow to fall from the clouds.

The dust storms of the Mars are the largest in the solar system, capable of blanketing the entire red planet and lasting for months. One theory as to why dust storms can grow so big on Mars starts with airborne dust particles absorbing sunlight, warming the Martian atmosphere in their vicinity. Warm pockets of air flow toward colder regions, generating winds. Strong winds lift more dust off the ground, which in turn heats the atmosphere, raising more wind and kicking up more dust.

## Orbital characteristics

The axis of Mars, like Earth's, is tilted with relation to the sun. This means that like Earth, the amount of sunlight falling on certain parts of the planet can vary widely during the year, giving Mars seasons.

However, the seasons that Mars experiences are more extreme than Earth's because the red planet's elliptical, oval-shaped orbit around the sun is more elongated than that of any of the other major planets. When Mars is closest to the sun, its southern hemisphere is tilted toward the sun, giving it a short, very hot summer, while the northern hemisphere experiences a short, cold winter. When Mars is farthest from the sun, the northern hemisphere is tilted toward the sun, giving it a long, mild summer, while the southern hemisphere experiences a long, cold winter.

## Composition & structure

Atmospheric composition (by volume):

95.32 percent carbon dioxide, 2.7 percent nitrogen, 1.6 percent argon, 0.13 percent oxygen, 0.08 percent carbon monoxide, minor amounts of water, nitrogen oxide, neon, hydrogen-deuterium-oxygen, krypton, xenon

Magnetic field: Mars currently has no global magnetic field, but there are regions of its crust that can be at least 10 times more strongly magnetized than anything measured on Earth, remnants of an ancient global magnetic field.

Chemical composition: Mars likely has a solid core composed of iron, nickel, and sulfur. The mantle of Mars is probably similar to Earth's in that it is composed mostly of peridotite, which is made up primarily of silicon, oxygen, iron and magnesium. The crust is probably largely made of the volcanic rock basalt, which is also common in the crusts of the Earth and the moon, although some crustal rocks, especially in the northern hemisphere, may be a form of andesite, a volcanic rock that contains more silica than basalt does.

Internal structure: Scientists think that on average, the Martian core is about 1,800 and 2,400 miles in diameter (3,000 and 4,000 km), its mantle is about 900 to 1,200 miles (5,400 to 7,200 km) wide and its crust is about 30 miles (50 km) thick.

## Orbit & rotation

Average distance from the sun: 141,633,260 miles (227,936,640 km). By comparison: 1.524 times that of Earth

Perihelion (closest): 128,400,000 miles (206,600,000 km). By comparison: 1.404 times that of Earth

Aphelion (farthest): 154,900,000 miles (249,200,000 km). By comparison: 1.638 times that of Earth

The moons of Mars

The two moons of Mars, Phobos and Deimos, were discovered by American astronomer Asaph Hall over the course of a week in 1877. Hall had almost given up his search for a moon of Mars, but his wife, Angelina, urged him on — he discovered Deimos the next night, and Phobos six days after that. He named the moons after the sons of the Greek war god Ares — Phobos means "fear," while Deimos means "rout."

Both Phobos and Deimos are apparently made of carbon-rich rock mixed with ice and are covered in dust and loose rocks. They are tiny next to Earth's moon, and are irregularly shaped, since they lack enough gravity to pull themselves into a more circular form. The widest Phobos gets is about 17 miles (27 km), and the widest Deimos gets is roughly nine miles (15 km).

Both moons are pockmarked with craters from meteor impacts. The surface of Phobos also possesses an intricate pattern of grooves, which may be cracks that formed after the impact created the moon's largest crater — a hole about 6 miles (10 km) wide, or nearly half the width of Phobos. They always show the same face to Mars, just as our moon does to Earth.

It remains uncertain how Phobos and Deimos were born. They may have been asteroids captured by Mars' gravitational pull, or they may have been formed in orbit around Mars the same time the planet came into existence. Ultraviolet light reflected from Phobos provides strong evidence for its capture origin, according to astronomers at the University of Padova in Italy.

Phobos is gradually spiraling toward Mars, drawing about 6 feet (1.8 meters) closer to the red planet each century. Within 50 million years, Phobos will either smash into Mars or break up and form a ring of debris around the planet.

Both moons are potential targets for exploration. One NASA plan envisions bombarding Phobos with small, spiky spherical rovers called hedgehogs.

The planet Mars is the fourth planet from the sun and named after the Roman God of War and is also called the Red Planet.See what makes Mars tick with this Space.com infographic looking inside the Red Planet.
Credit: Karl Tate, SPACE.com
View full size image

## Research & exploration

The first person to watch Mars with a telescope was Galileo Galilei, and in the century after him, astronomers discovered its polar ice caps. In the 19th and 20th centuries, researchers believed they saw a network of long, straight canals on Mars, hinting at civilization, although later these often proved to be mistaken interpretations of dark regions they saw.

Robot spacecraft began observing Mars in the 1960s, with the United States launching Mariner 4 there in 1964 and Mariners 6 and 7 in 1969. They revealed Mars to be a barren world, without any signs of the life or civilizations people had imagined there. In 1971, Mariner 9 orbited Mars, mapping about 80 percent of the planet and discovering its volcanoes and canyons.

NASA's Viking 1 lander touched down onto the surface of Mars in 1976, the first successful landing onto the Red Planet. It took the first close-up pictures of the Martian surface but found no strong evidence for life.

The next two craft to successfully reach Mars were the Mars Pathfinder, a lander, and Mars Global Surveyor, an orbiter, both launched in 1996. A small robot onboard Pathfinder named Sojourner — the first wheeled rover to explore the surface of another planet — ventured over the planet's surface analyzing rocks.

In 2001, the United States launched the Mars Odyssey probe, which discovered vast amount of water ice beneath the Martian surface, mostly in the upper three feet (one meter). It remains uncertain whether more water lies underneath, since the probe cannot see water any deeper.

In 2003, the closest Mars had passed to Earth in nearly 60,000 years, NASA launched two rovers, nicknamed Spirit and Opportunity, which explored different regions of the Martian surface, and both found signs that water once flowed on the planet's surface. In 2008, NASA sent another mission, Phoenix, to land in the northern plains of Mars and search for water,

Two orbiters — NASA's Mars Reconnaissance Orbiter and ESA's Mars Express — are keeping Mars Odyssey company over the planet. In 2011, NASA's Mars Science Laboratory mission, with its rover named Mars Curiosity, began to investigate Martian rocks to determine the geologic processes that created them and find out more about the present and past habitability of Mars. Among its findings is the first meteorite on the surface of the red planet.

In September 2014, India’s Mars Orbiter Mission reached the red planet, making it the fourth nation to successfully enter orbit around Mars.

Robots aren’t the only ones looking to buy a ticket to Mars. A workshop group of government, academic, and industry scientists have found that a NASA-led manned mission to Mars should be possible by the 2030s. But NASA isn’t the only one with Martian astronaut hopefuls.. The Mars One colony project is looking to send private citizens on a one-way trip to the red planet.

## Possibility of life

Mars could have once harbored life. Some conjecture that life might still exist there even today. A number of researchers have even speculated that life on Earth may have seeded Mars, or that life on Mars seeded Earth.

The most public scientific claim for life on Mars came in 1996. Geologist David McKay at NASA's Johnson Space Center in Houston and his colleagues focused on rocks blasted off the surface of Mars by cosmic impacts that landed on Earth. Within they found complex organic molecules, grains of a mineral called magnetite that can form within some kinds of bacteria, and tiny structures that resembled fossilized microbes. However, these claims have proven controversial, and there is no consensus as to whether they are signs of life.

Mars may have possessed oceans on its surface in the past, providing an environment for life to develop. Although the red planet is a cold desert today, researchers suggest that liquid water may be present underground, providing a potential refuge for any life that might still exist there. The rover Curiosity has found evidence for a lake that could have once supported life on the red planet, after previously establishing that the planet had the key ingredients present for life to evolve.

Enthusiasm and excitement on Earth over the possibility of life on the red planet are revealed by the flurry of excitement that greets interesting objects spotted by orbiters and landers. While the Face on Mars garnered attention for the past four decades after it was first spotted by Viking 1, rovers today show close-ups of objects — such as a weathered Martian rock claimed to be a ‘thigh bone’ and a likely shiny rock that raised furor on the internet as a UFO light.

Additional resources

- Read about and see pictures of more than 40 missions to Mars.
- Follow the rover Curiosity as it makes its way across the Martian terrain.
- Learn more about Mars at NASA's Solar System Exploration website.

Related:

- How Big is Mars?
- How Far Away is Mars?
- Does Mars Have an Atmosphere?
- How Cold is Mars?
- What is Mars Made Of?
- How Was Mars Formed?

Also see:

- Solar System Planets overview
- Solar System Facts overview

Learn more about each of the primary planets:

- Mercury
- Venus
- Earth
- Jupiter
- Saturn
- Uranus
- Neptune
- Pluto

More from Space.com
AUTHOR BIO

### Charles Q. Choi

Charles Q. Choi is a contributing writer for Space.com and Live Science. He covers all things human origins and astronomy as well as physics, animals and general science topics. Charles has a Master of Arts degree from the University of Missouri-Columbia, School of Journalism and a Bachelor of Arts degree from the University of South Florida. Charles has visited every continent on Earth, drinking rancid yak butter tea in Lhasa, snorkeling with sea lions in the Galapagos and even climbing an iceberg in Antarctica.
Charles Q. Choi on